@@ -8,13 +8,13 @@ get_kr_df <- function(model_object) {
   out
 }
 
-konfound_lmer <- function(model_object, tested_variable_string, test_all, alpha, tails, to_return) {
+konfound_lmer <- function(model_object, tested_variable_string, test_all, alpha, tails, index, to_return) {
   tidy_output <- broom.mixed::tidy(model_object) # tidying output
 
   if (test_all == FALSE) {
     coef_df <- tidy_output[tidy_output$term == tested_variable_string, ]
-    est_eff <- round(coef_df$estimate, 3)
-    std_err <- round(coef_df$std.error, 3)
+    est_eff <- coef_df$estimate
+    std_err <- coef_df$std.error
     df_kr <- get_kr_df(model_object)
     df_kr <- df_kr[names(df_kr) == tested_variable_string]
   } else {
@@ -34,6 +34,7 @@ konfound_lmer <- function(model_object, tested_variable_string, test_all, alpha,
       n_covariates = 0,
       alpha = alpha,
       tails = tails,
+      index = index,
       nu = 0,
       to_return = to_return,
       model_object = model_object,
