@@ -27,6 +27,7 @@ test_sensitivity <- function(est_eff,
                              n_covariates,
                              alpha,
                              tails,
+                             index,
                              nu,
                              to_return,
                              model_object,
@@ -116,7 +117,7 @@ test_sensitivity <- function(est_eff,
     )
     konfound_output <- create_konfound_class(konfound_output)
     names(konfound_output) <- to_return
-    output_print(est_eff, beta_threshold, bias, sustain, nu, recase, obs_r, critical_r, r_con, itcv, alpha)
+    output_print(est_eff, beta_threshold, bias, sustain, nu, recase, obs_r, critical_r, r_con, itcv, alpha, index)
 
     cat("\n")
     message(paste("Print output created by default. Created", length(konfound_output), "other forms of output. Use list indexing or run summary() on the output to see how to access."))
@@ -131,7 +132,7 @@ test_sensitivity <- function(est_eff,
   } else if (to_return == "corr_plot") {
     return(plot_correlation(r_con = r_con, obs_r = obs_r, critical_r = critical_r))
   } else if (to_return == "print") {
-    return(output_print(est_eff, beta_threshold, bias, sustain, nu, recase, obs_r, critical_r, r_con, itcv, alpha))
+    return(output_print(est_eff, beta_threshold, bias, sustain, nu, recase, obs_r, critical_r, r_con, itcv, alpha, index))
   } else if (to_return == "table") {
     return(output_table(model_object, tested_variable))
   } else {
